import {
  select,
  csv,
  extent,
  scaleLinear,
  scaleTime,
  axisLeft,
  axisBottom,
  area,
  curveBasis,
  max
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const circleRadius = 5;
const xValue = d => d.timestamp;
const yValue = d => d.temperature;
const margin = {top: 60, right: 20, bottom: 85, left: 85};
const innerWidth = width - margin.right - margin.left;
const innerHeight = height - margin.top - margin.bottom;

const title = 'Evolution of the temperature in SF';
const xAxisLabel ='Date';
const yAxisLabel = 'Temperature (°C)';

const render = data => {
  const xScale = scaleTime()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth])
  const yScale = scaleLinear()
  	.domain([0, max(data, yValue)])
  	.range([innerHeight, 0])
  	.nice();
            
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(15)
  	.ticks(5);
  const xAxisG = g.append('g')
  	.call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`)
  	
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
  	.text(xAxisLabel)
		.attr('class', 'axisLabel')
  	.attr('x', innerWidth / 2)
  	.attr('y', 70);
  
	const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(15);
  const yAxisG = g.append('g')
  	.call(yAxis)
  	
  yAxisG.select('.domain').remove();
  
  yAxisG.append('text')
  	.text(yAxisLabel)
  	.attr('transform', 'rotate(-90)')
		.attr('class', 'axisLabel')
  	.attr('x', -innerHeight / 2)
  	.attr('y', -55)
  	.attr('text-anchor', 'middle');
  
  g.append('text')
  	.text(title)
  	.attr('y', -20)
  	.attr('x', innerWidth / 2)
  	.attr('class', 'title');
  
  const areaGenerator = area()
  	.x(d => xScale(xValue(d)))
  	.y0(innerHeight)
  	.y1(d => yScale(yValue(d)))
  	.curve(curveBasis);
  
  g.append('path')
  	.attr('d', areaGenerator(data))
  	.attr('class', 'area-path');

};

csv('https://vizhub.com/curran/datasets/temperature-in-san-francisco.csv')
	.then(data => {
  	data.forEach(d => {
      d.temperature = +d.temperature;
      d.timestamp = new Date(d.timestamp);
    });
  	console.log(data);
  	render(data);
});